#
# spec file for package python-onnx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1

Name:           python-onnx
Version:        1.6.0
Release:        2.8
Summary:        Open Neural Network Exchange
License:        MIT
Group:          Development/Languages/Python
URL:            https://onnx.ai/
Source0:        https://github.com/onnx/onnx/archive/v%{version}.tar.gz#/onnx-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pybind11}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  protobuf-devel
BuildRequires:  python-pybind11-devel
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-protobuf
Requires:       python-six
Requires:       python-typing_extensions >= 3.6.2.1
Suggests:       python-mypy >= 0.600

%python_subpackages

%description
Open format to represent deep learning models. With ONNX, AI developers can more easily move models between state-of-the-art tools and choose the combination that is best for them. ONNX is developed and supported by a community of partners.

%package devel
Summary:        C/C++ - header files which are used for development
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description devel
The headers and other files needed for the development.

%prep
%setup -q -n onnx-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
shebang_files="%{python_sitearch}/onnx/backend/test/stat_coverage.py %{python_sitearch}/onnx/defs/gen_doc.py %{python_sitearch}/onnx/gen_proto.py"
for file in $shebang_files ; do
  sed -i 's@/usr/bin/env python@/usr/bin/python3@' %{buildroot}/$file
  chmod 755 %{buildroot}/$file
done
# check fails with buitling typing of python 3.7.3
# https://github.com/pybind/pybind11/issues/1949

%files %{python_files}
%doc README.md
%license LICENSE 
%python3_only %{_bindir}/check-model
%python3_only %{_bindir}/check-node
%python3_only %{_bindir}/backend-test-tools
%{python_sitearch}/*
%exclude %{python_sitearch}/onnx/*.[hc]
%exclude %{python_sitearch}/onnx/common
%exclude %{python_sitearch}/onnx/optimizer
%exclude %{python_sitearch}/onnx/version_converter
%exclude %{python_sitearch}/onnx/shape_inference

%files %{python_files devel}
%{python_sitearch}/onnx/*.[hc]
%{python_sitearch}/onnx/common
%{python_sitearch}/onnx/optimizer
%{python_sitearch}/onnx/version_converter
%{python_sitearch}/onnx/shape_inference

%changelog
* Wed Jan  8 2020 Christian Goll <cgoll@suse.com>
- moved necessary defs from devel to main package
* Mon Oct 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add python-onnx-rpmlintrc to sources
* Fri Oct 18 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix armv7 build
* Tue Oct  8 2019 Christian Goll <cgoll@suse.com>
- updated to version 1.6.0
* Fri Mar 22 2019 Christian Goll <cgoll@suse.com>
- initial commit of onnx created with py2pack
